---
title: Just Get 9 for Amstrad CPC
author: Stéphane Gourichon (cpcitor)
---

Just Get 9 for Amstrad CPC
==========================

The prod in a few words
-----------------------

A tile game for the Amstrad CPC.  If you like 2048, tetris, coloris, color flood, you'll like it.


Features
--------

* a gameplay based on alignment of tiles, which changes when tiles disappear, letting new ones fall and fill the gaps
* rich dynamics making gameplay entertaining as you progress in skills
* play with joystick or keyboard (arrows, qaop)
* a big colorful playfield (vertical overscan 256x256 instead of the normal 320x200)
* animation at solid 50Hz
* music
* digitized speech!
* a few bells and whistles to be discovered...

Direct credits (see more credits below):

* project, coding, text, video, by cpcitor
* music by The Other Days


How it looks like
-----------------

![title page image](illustrations/justget9_title.png)![game sample image](illustrations/justget9_ingame.png)![base rule](illustrations/justget9_rule.png)![menu](illustrations/justget9_menu.png)![in-game menu](illustrations/justget9_ingame_menu.png)


Why this game?
--------------

This game is really interesting to play.  Its rules are simple, but
result in rich dynamics.

To progress towards the goal, at each move the player select a tile of
a "domain" (group of tiles of same value).  This tile increases value
and the rest of the domain disappears, making room for new random
tiles from the top.

An important part of how the player can influence the game is that the
player chooses which tile of the domain they play, which decides where
the new tile appears and where disappearing tiles cause other tiles to
fall, creating new opportunities for aligned tiles of the same value
-> new groups.

This makes possible to "clear out" obstructing tiles in various ways.
Watch out not to "break" interesting domains by removing tiles under
some parts.

First moves are really easy and provide a quick intuitive
understanding, yet difficult gradually increases, maintaining a nice
level of challenge and thinking all along.


Files to run the prod
---------------------

### Disk image: justget9_with_intro.dsk

This is a disk image file.

#### From a disk image file to a real or emulated CPC accessing it.

Many options.  You can:

* get a CPC emulator for a modern machine (outdated lists on [cpcwiki](https://www.cpcwiki.eu/index.php/Category:Emulator) or [wikipedia](https://en.wikipedia.org/wiki/List_of_computer_system_emulators#Amstrad_CPC)), insert the image as virtual disc,
* *easiest on hardware* through the audio cable described in the audio section to instruct a real CPC to create a real disc from the image with [dsk2cdt2disc](https://github.com/pelrun/dsk2cdt2disc) -- tested with a CPC-6128, might also work with a CPC464+DDI1+pseudo-tape.
* **or** easy but needs a modern device, transfer to a storage like a SD-Card then use HxC, M4 or [other](https://www.cpcwiki.eu/index.php/Category:DATA_Storage) to let the CPC access the card,
* **or** transfer to a PC-style 3.5-inch real disk ([Have Linux make a USB floppy drive write to a disk that a CPC can then read.](https://www.cpcwiki.eu/forum/technical-support/have-linux-make-a-usb-floppy-write-a-disk-that-a-cpc-can-read/)) then read that disk on a CPC (needs a flat ribbon cable, see [Guide on how to connect a 3.5&quot; drive to a CPC6128/664 - CPCWiki](https://www.cpcwiki.eu/index.php/Guide_on_how_to_connect_a_3.5%22_drive_to_a_CPC6128/664)),
* **or** plug a CPC drive to a PC (needs a flat ribbon cable, [see Connect a 3 inch drive to a PC - CPCWiki](https://www.cpcwiki.eu/index.php/Connect_a_3_inch_drive_to_a_PC)) and with this drive transfer the image to a real CPC-style 3-inch disk (via Linux commands like `dd`), then you can read the disk with a real CPC

#### Run intro then game

To run the intro section, type this:

    run"cpcitor

Press any key during the intro to skip to the game.

#### Run only game

To go straight into the game:

    run"justget9

You can also transfer the image to a real floppy disk, but that’s beyond
this text.

### Tape images: justget9_1000baud.cdt and justget9_2000baud.cdt

Tape images. Open in a CPC emulator, type this:

If the emulated CPC has a disk (disc) drive, first type:

    |tape

or for a French CPC:

    ùtape

Then in all case:

    run"

You can also convert those images to audio files.  See below, I prepared audio files so that you don't have to!

### Mostly for CPC464: justget9_1000baud.wav

This is an audio file of duration 3 minutes 38 seconds.

* Use the jack output of a modern machine (PC, smartphone, etc) and any decent consumer-grade audio cassette recorder to transfer the audio from the WAV file to an audio cassette.
* Put the audio cassette in a CPC464.

You can use `justget9_2000baud.wav` which is twice faster, but less reliable.  CPCs are old and some will work only with 1000baud version.

If the CPC has a disk (disc) drive, first type:

    |tape

or for a French CPC:

    ùtape

Then in all case:

    run"


### Mostly for CPC6128: justget9_2000baud.wav

This is an audio file of duration 1 minutes 53 seconds.

* If you have a special jack-to-CPC-DIN cable, then plug the jack side on the sound output of a modern machine (PC, smartphone, etc) and the DIN side to a real CPC 6128, and play the audio file at fairly loud volume.
* Alternatively, if you have a pseudo-cassette with a cable ending with a 3.5mm jack, put it in a CPC464,

If the CPC has a disk (disc) drive, first type:

    |tape

or for a French CPC:

    ùtape

Then in all case:

    run"



Tech corner
-----------

This game follows [color-flood-for-amstrad-cpc](https://github.com/cpcitor/color-flood-for-amstrad-cpc).
Like its predecessor, it is written mostly in C, with the time-critical pieces written in assembly.

It was written with the [cpc-dev-tool-chain framework for C programming on the Amstrad CPC](https://github.com/cpcitor/cpc-dev-tool-chain).


Credits
-------

* A.M.Sugar for Amstrad CPC series,
* L.Torvalds for Linux, git,
* many people for GNU, Debian, Ubuntu,
* S.Dutta, P.K.Krause for SDCC,
* K.Thacker for many things CPC,
* J.Pelletier for hex2bin,
* Users and admins at CPCWiki and forum,
* cpc-dev-tool-chain users,
* F.Gallego(lronaldo) for understanding the power of cpc-dev-tool-chain and forking it into CPCTelera,
* C.Pitrat, Sebhz for Caprice32,
* J.Nevo(Thargan) for ArkosTracker2,
* C.N.Gonzalez(CNGSoft) for CPCEC,
* Canonical for Ubuntu font,
* Author of public domain X11 font "fixed",
* Roudoudou for Rasm,
* Norecess for an early report on SDCC on CPC and his cpcec-plus tracing Z80 code with symbols,
* Borilla for borilla.co.uk/z80.html,
* Z80Heaven for the Z80 reference
* C.Robertson for Roboto font,
* M. Lind for Exomizer,
* J.T.Gomez (Metalbrain) for deexo,


Copying
-------

As the creator of this program and its encoded forms (zip archive containing disk image, tape image, audio file) I give permission to anyone, anywhere, at any time, to:

* copy and distribue the original zip file free of charge, by any means,
* include the game along with metadata in databases/catalog/ftp-site/etc of CPC-related, retro-related, demoscene-related or more generally, catalog of artifact (e.g. online encyclopedia), in the form of the original zip file, along with text that may or may not include part of this README file, ensuring proper credits, and images included in the zip file and/or high-quality screenshots from an emulated run or a real CPC.
* it is permitted that the database/catalog offers distribution (e.g. listing, download) of individual artifacts (disk image, tape image) if the original zip file is offered among the other options.
* if the distribution process requires short names (8+3 characters) it is permitted to shorten the name of the zip file to `justget9.zip`
* it is permitted (although not recommended) to create another archive file by uncompressing the zip file in a directory and recompressing the directory content with another archive program like 7z, if decompression programs for the resulting file are publicly available under an open-source licence and widely distributed on major platforms and portable on other platforms, and use/distribute the resulting archive instead of the original zip files.


Source code
-----------

I'm considering releasing the source code with an Open Source licence, which will provide you with additional rights.

If you don't find it easily on the net, please ask for it through the channel where this file came, or figure out how to contact me.


Version information / Changelog
-------------------------------

This is release "patch 2".

### Changes in "patch 1"

* When you reach 9 (or higher), the background of the "you win" text is now darkened for more readability. (Thanks @roudoudou for noticing the reduced readability.)
* The button to start playing is not longer labeled "PLAYGRID" but "PLAY", or "GRID" when game is over.  (Indeed you can see and study the grid as will, after game is over before starting a new game.) (Thanks Didier, @eto, @Logiker for reporting the wish to change wording.)
* Fix broken link in this very README file. (Thanks to Nicholas Campbell from cpcgamereviews.com for reporting.)
* Add section about copying.

### Changes in "patch 2"

* In-game menu explicitly offers to quit the current game.
* In a number of circumstances, display current "achievement".  It is the value, number of moves and time since game beginning *at the moment of the highest tile obtained*.  Shown:
    * when a new number is achieved,
    * in the in-game menu,
    * in the "quit game?" screen
    * on game over
* "How to play" page mentions that pressing "Esc" shows achievement and menu.
* Adjusted main menu layout.
* Improved consistency of the user experience overall (e.g. the main menu shows either plain background or last grid, but no remnant of previous screen, "game over" display is the same whether it just happened or you return to the grid).
* In main screen without current game, pressing Esc screen advances to next automatic screen, instead of starting a new game.
* C part compiled with stronger optimization level, yielding slightly shorter code.
* Minor manual cleanup, removed dead code.
* Minor internal optimizations here and there.
